==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppPublicCertificateSlotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.PublicCertificateLocation
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Public certificate object
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppPublicCertificateSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/publicCertificates/{publicCertificateName}
 * ```
 * @property blob Public Certificate byte array
 * @property kind Kind of resource.
 * @property name Name of the app.
 * @property publicCertificateLocation Public Certificate Location
 * @property publicCertificateName Public certificate name.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property slot Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
 */
public data class WebAppPublicCertificateSlotArgs(
    public val blob: Output<String>? = null,
    public val kind: Output<String>? = null,
    public val name: Output<String>? = null,
    public val publicCertificateLocation: Output<PublicCertificateLocation>? = null,
    public val publicCertificateName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val slot: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs> {
    override fun toJava(): com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs =
        com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs.builder()
            .blob(blob?.applyValue({ args0 -> args0 }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .publicCertificateLocation(
                publicCertificateLocation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .publicCertificateName(publicCertificateName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .slot(slot?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAppPublicCertificateSlotArgs].
 */
@PulumiTagMarker
public class WebAppPublicCertificateSlotArgsBuilder internal constructor() {
    private var blob: Output<String>? = null

    private var kind: Output<String>? = null

    private var name: Output<String>? = null

    private var publicCertificateLocation: Output<PublicCertificateLocation>? = null

    private var publicCertificateName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var slot: Output<String>? = null

    /**
     * @param value Public Certificate byte array
     */
    @JvmName("tawepgwuouiomdnb")
    public suspend fun blob(`value`: Output<String>) {
        this.blob = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("tmbcahllpevcduqh")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("oofeapfuvltbtdkl")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Public Certificate Location
     */
    @JvmName("bwglmgjudwvqteex")
    public suspend fun publicCertificateLocation(`value`: Output<PublicCertificateLocation>) {
        this.publicCertificateLocation = value
    }

    /**
     * @param value Public certificate name.
     */
    @JvmName("jcqmbfxjnwyfnobo")
    public suspend fun publicCertificateName(`value`: Output<String>) {
        this.publicCertificateName = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("goyjpgegdonyhvwx")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("myonuxxrbimlsfgs")
    public suspend fun slot(`value`: Output<String>) {
        this.slot = value
    }

    /**
     * @param value Public Certificate byte array
     */
    @JvmName("lfmdbmiddqfrycjl")
    public suspend fun blob(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blob = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("jxvrgmyjnipfskoo")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("mqnwrptxsqeuhmwk")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Public Certificate Location
     */
    @JvmName("hndcltqdwkqsmkry")
    public suspend fun publicCertificateLocation(`value`: PublicCertificateLocation?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicCertificateLocation = mapped
    }

    /**
     * @param value Public certificate name.
     */
    @JvmName("qbrjtesawudlsgaq")
    public suspend fun publicCertificateName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicCertificateName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("oflsiyfpfinrlxvb")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("sqepbrhvbsuitmjy")
    public suspend fun slot(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slot = mapped
    }

    internal fun build(): WebAppPublicCertificateSlotArgs = WebAppPublicCertificateSlotArgs(
        blob = blob,
        kind = kind,
        name = name,
        publicCertificateLocation = publicCertificateLocation,
        publicCertificateName = publicCertificateName,
        resourceGroupName = resourceGroupName,
        slot = slot,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppPublicCertificateSlotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.PublicCertificateLocation
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Public certificate object
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppPublicCertificateSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/publicCertificates/{publicCertificateName}
 * ```
 * @property blob Public Certificate byte array
 * @property kind Kind of resource.
 * @property name Name of the app.
 * @property publicCertificateLocation Public Certificate Location
 * @property publicCertificateName Public certificate name.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property slot Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
 */
public data class WebAppPublicCertificateSlotArgs(
    public val blob: Output<String>? = null,
    public val kind: Output<String>? = null,
    public val name: Output<String>? = null,
    public val publicCertificateLocation: Output<PublicCertificateLocation>? = null,
    public val publicCertificateName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val slot: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs> {
    override fun toJava(): com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs =
        com.pulumi.azurenative.web.WebAppPublicCertificateSlotArgs.builder()
            .blob(blob?.applyValue({ args0 -> args0 }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .publicCertificateLocation(
                publicCertificateLocation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .publicCertificateName(publicCertificateName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .slot(slot?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAppPublicCertificateSlotArgs].
 */
@PulumiTagMarker
public class WebAppPublicCertificateSlotArgsBuilder internal constructor() {
    private var blob: Output<String>? = null

    private var kind: Output<String>? = null

    private var name: Output<String>? = null

    private var publicCertificateLocation: Output<PublicCertificateLocation>? = null

    private var publicCertificateName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var slot: Output<String>? = null

    /**
     * @param value Public Certificate byte array
     */
    @JvmName("trysqddghxuhqnwo")
    public suspend fun blob(`value`: Output<String>) {
        this.blob = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("mmucltylqbsgsiqd")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("pjvsykjqgwjfnsno")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Public Certificate Location
     */
    @JvmName("evwsgutbwdwflgeq")
    public suspend fun publicCertificateLocation(`value`: Output<PublicCertificateLocation>) {
        this.publicCertificateLocation = value
    }

    /**
     * @param value Public certificate name.
     */
    @JvmName("phumjuiyjnmfqynh")
    public suspend fun publicCertificateName(`value`: Output<String>) {
        this.publicCertificateName = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("kqgeoeqggcbnnqgy")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("vntbolphbyakdwep")
    public suspend fun slot(`value`: Output<String>) {
        this.slot = value
    }

    /**
     * @param value Public Certificate byte array
     */
    @JvmName("fpwbtwpkwctiplbr")
    public suspend fun blob(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.blob = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("arrqafgsripeepvi")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("wfcphkpppqdqciww")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Public Certificate Location
     */
    @JvmName("kbqfdjokyfrfaesi")
    public suspend fun publicCertificateLocation(`value`: PublicCertificateLocation?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicCertificateLocation = mapped
    }

    /**
     * @param value Public certificate name.
     */
    @JvmName("khsirdvpoiwdepaf")
    public suspend fun publicCertificateName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicCertificateName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("ksailsospubvnqcq")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("hinrjoijfkratltt")
    public suspend fun slot(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slot = mapped
    }

    internal fun build(): WebAppPublicCertificateSlotArgs = WebAppPublicCertificateSlotArgs(
        blob = blob,
        kind = kind,
        name = name,
        publicCertificateLocation = publicCertificateLocation,
        publicCertificateName = publicCertificateName,
        resourceGroupName = resourceGroupName,
        slot = slot,
    )
}
